@@ -176,7 +176,7 @@ sub new {
       OpenGL::glutMotionFunc( \&_pdl_fake_MotionNotify );
       OpenGL::glutDisplayFunc( \&_pdl_display_wrapper );
 
-      OpenGL::glutSetOption(OpenGL::GLUT_ACTION_ON_WINDOW_CLOSE, OpenGL::GLUT_ACTION_GLUTMAINLOOP_RETURNS) if $OpenGL::_have_freeglut;
+      OpenGL::glutSetOption(OpenGL::GLUT_ACTION_ON_WINDOW_CLOSE, OpenGL::GLUT_ACTION_GLUTMAINLOOP_RETURNS) if OpenGL::_have_freeglut();
 
       OpenGL::glutMainLoopEvent();       # pump event loop so window appears
    }
